@@ -75,7 +75,7 @@ class HyperState(ABC, Generic[C, S]):
             if checkpoint is not None:
                 print(f"Resuming from checkpoint {checkpoint}")
                 initial_config = checkpoint
-                if str(checkpoint).startswith("latest"):
+                if checkpoint.name.startswith("latest"):
                     self._last_checkpoint = checkpoint
         else:
             self.checkpoint_dir = None
@@ -472,7 +472,7 @@ def atomic_move(src: str, dst: str) -> None:
             # atomic.  We intersperse a random UUID so if different processes
             # are copying into `<dst>`, they don't overlap in their tmp copies.
             copy_id = uuid.uuid4()
-            tmp_dst = f"{dst}.{copy_id}.tmp" % (dst, copy_id)
+            tmp_dst = f"{dst}.{copy_id}.tmp"
             shutil.copyfile(src, tmp_dst)
 
             # Then do an atomic rename onto the new name, and clean up the
